#!/usr/bin/env bash

# battery
ln -s battery-020.svg battery-caution.svg
ln -s battery-020-charging.svg battery-caution-charging-symbolic.svg
ln -s battery-020.svg battery-caution-symbolic.svg

ln -s battery-000-charging.svg battery-empty-charging-symbolic.svg
ln -s battery-000.svg battery-empty-symbolic.svg
ln -s battery-100.svg battery_full.svg
ln -s battery-charged.svg battery-full-charged-symbolic.svg
ln -s battery-100-charging.svg battery-full-charging-symbolic.svg
ln -s battery-100.svg battery-full-symbolic.svg

ln -s battery-060-charging.svg battery-good-charging-symbolic.svg
ln -s battery-060.svg battery-good-symbolic.svg
ln -s battery-040.svg battery-low.svg
ln -s battery-040-charging.svg battery-low-charging-symbolic.svg
ln -s battery-040.svg battery-low-symbolic.svg
ln -s battery-000.svg battery-missing-symbolic.svg

ln -s battery-charged.svg battery_charged.svg
ln -s battery-000.svg battery-empty.svg
ln -s battery-000.svg battery_empty.svg
ln -s battery-000.svg battery-missing.svg

# unity-battery
ln -s ac-adapter-symbolic.svg unity-ac-adapter.svg
ln -s battery-020.svg unity-battery-caution.svg
ln -s battery-020-charging.svg unity-battery-caution-charging-symbolic.svg
ln -s battery-020.svg unity-battery-caution-symbolic.svg

ln -s battery-000-charging.svg unity-battery-empty-charging-symbolic.svg
ln -s battery-000.svg unity-battery-empty-symbolic.svg
ln -s battery-100.svg unity-battery_full.svg
ln -s battery-charged.svg unity-battery-full-charged-symbolic.svg
ln -s battery-100-charging.svg unity-battery-full-charging-symbolic.svg
ln -s battery-100.svg unity-battery-full-symbolic.svg

ln -s battery-060-charging.svg unity-battery-good-charging-symbolic.svg
ln -s battery-060.svg unity-battery-good-symbolic.svg
ln -s battery-040.svg unity-battery-low.svg
ln -s battery-040-charging.svg unity-battery-low-charging-symbolic.svg
ln -s battery-040.svg unity-battery-low-symbolic.svg
ln -s battery-000.svg unity-battery-missing-symbolic.svg

ln -s battery-000.svg unity-battery-000.svg
ln -s battery-020.svg unity-battery-020.svg
ln -s battery-040.svg unity-battery-040.svg
ln -s battery-060.svg unity-battery-060.svg
ln -s battery-080.svg unity-battery-080.svg
ln -s battery-100.svg unity-battery-100.svg

ln -s battery-000-charging.svg unity-battery-000-charging.svg
ln -s battery-020-charging.svg unity-battery-020-charging.svg
ln -s battery-040-charging.svg unity-battery-040-charging.svg
ln -s battery-060-charging.svg unity-battery-060-charging.svg
ln -s battery-080-charging.svg unity-battery-080-charging.svg
ln -s battery-100-charging.svg unity-battery-100-charging.svg

ln -s battery-charged.svg unity-battery_charged.svg
ln -s battery-000.svg unity-battery-empty.svg
ln -s battery-000.svg unity-battery_empty.svg
ln -s battery-000.svg unity-battery-missing.svg

# gpm-primary
ln -s battery-000.svg gpm-primary-000.svg
ln -s battery-020.svg gpm-primary-020.svg
ln -s battery-040.svg gpm-primary-040.svg
ln -s battery-060.svg gpm-primary-060.svg
ln -s battery-080.svg gpm-primary-080.svg
ln -s battery-100.svg gpm-primary-100.svg

ln -s battery-000-charging.svg gpm-primary-000-charging.svg
ln -s battery-020-charging.svg gpm-primary-020-charging.svg
ln -s battery-040-charging.svg gpm-primary-040-charging.svg
ln -s battery-060-charging.svg gpm-primary-060-charging.svg
ln -s battery-080-charging.svg gpm-primary-080-charging.svg
ln -s battery-100-charging.svg gpm-primary-100-charging.svg

ln -s battery-charged.svg gpm-primary-charged.svg
ln -s battery-charged.svg gpm-primary_charged.svg
ln -s battery-000.svg gpm-primary-empty.svg
ln -s battery-000.svg gpm-primary_empty.svg
ln -s battery-000.svg gpm-primary-missing.svg

# gpm-ups
ln -s battery-000.svg gpm-ups-000.svg
ln -s battery-020.svg gpm-ups-020.svg
ln -s battery-040.svg gpm-ups-040.svg
ln -s battery-060.svg gpm-ups-060.svg
ln -s battery-080.svg gpm-ups-080.svg
ln -s battery-100.svg gpm-ups-100.svg

ln -s battery-000-charging.svg gpm-ups-000-charging.svg
ln -s battery-020-charging.svg gpm-ups-020-charging.svg
ln -s battery-040-charging.svg gpm-ups-040-charging.svg
ln -s battery-060-charging.svg gpm-ups-060-charging.svg
ln -s battery-080-charging.svg gpm-ups-080-charging.svg
ln -s battery-100-charging.svg gpm-ups-100-charging.svg

ln -s battery-charged.svg gpm-ups-charged.svg
ln -s battery-charged.svg gpm-ups_charged.svg
ln -s battery-000.svg gpm-ups-empty.svg
ln -s battery-000.svg gpm-ups_empty.svg
ln -s battery-000.svg gpm-ups-missing.svg

# unity-gpm-battery
ln -s battery-000.svg unity-gpm-battery-000.svg
ln -s battery-020.svg unity-gpm-battery-020.svg
ln -s battery-040.svg unity-gpm-battery-040.svg
ln -s battery-060.svg unity-gpm-battery-060.svg
ln -s battery-080.svg unity-gpm-battery-080.svg
ln -s battery-100.svg unity-gpm-battery-100.svg

ln -s battery-000-charging.svg unity-gpm-battery-000-charging.svg
ln -s battery-020-charging.svg unity-gpm-battery-020-charging.svg
ln -s battery-040-charging.svg unity-gpm-battery-040-charging.svg
ln -s battery-060-charging.svg unity-gpm-battery-060-charging.svg
ln -s battery-080-charging.svg unity-gpm-battery-080-charging.svg
ln -s battery-100-charging.svg unity-gpm-battery-100-charging.svg

ln -s battery-charged.svg unity-gpm-primary-charged.svg
ln -s battery-charged.svg unity-gpm-primary_charged.svg
ln -s battery-000.svg unity-gpm-primary-empty.svg
ln -s battery-000.svg unity-gpm-primary_empty.svg
ln -s battery-000.svg unity-gpm-primary-missing.svg

# xfpm-primary
ln -s ac-adapter-symbolic.svg xfpm-ac-adapter.svg
ln -s battery-000.svg xfpm-primary-000.svg
ln -s battery-020.svg xfpm-primary-020.svg
ln -s battery-040.svg xfpm-primary-040.svg
ln -s battery-060.svg xfpm-primary-060.svg
ln -s battery-080.svg xfpm-primary-080.svg
ln -s battery-100.svg xfpm-primary-100.svg

ln -s battery-000-charging.svg xfpm-primary-000-charging.svg
ln -s battery-020-charging.svg xfpm-primary-020-charging.svg
ln -s battery-040-charging.svg xfpm-primary-040-charging.svg
ln -s battery-060-charging.svg xfpm-primary-060-charging.svg
ln -s battery-080-charging.svg xfpm-primary-080-charging.svg
ln -s battery-100-charging.svg xfpm-primary-100-charging.svg

ln -s battery-charged.svg xfpm-primary-charged.svg
ln -s battery-charged.svg xfpm-primary_charged.svg
ln -s battery-000.svg xfpm-primary-empty.svg
ln -s battery-000.svg xfpm-primary_empty.svg
ln -s battery-000.svg xfpm-primary-missing.svg

ln -s gpm-keyboard-000.svg xfpm-keyboard-000.svg
ln -s gpm-keyboard-020.svg xfpm-keyboard-020.svg
ln -s gpm-keyboard-040.svg xfpm-keyboard-040.svg
ln -s gpm-keyboard-060.svg xfpm-keyboard-060.svg
ln -s gpm-keyboard-080.svg xfpm-keyboard-080.svg
ln -s gpm-keyboard-100.svg xfpm-keyboard-100.svg
ln -s gpm-mouse-000.svg xfpm-mouse-000.svg
ln -s gpm-mouse-020.svg xfpm-mouse-020.svg
ln -s gpm-mouse-040.svg xfpm-mouse-040.svg
ln -s gpm-mouse-060.svg xfpm-mouse-060.svg
ln -s gpm-mouse-080.svg xfpm-mouse-080.svg
ln -s gpm-mouse-100.svg xfpm-mouse-100.svg
ln -s gpm-phone-000.svg xfpm-phone-000.svg
ln -s gpm-phone-020.svg xfpm-phone-020.svg
ln -s gpm-phone-040.svg xfpm-phone-040.svg
ln -s gpm-phone-060.svg xfpm-phone-060.svg
ln -s gpm-phone-080.svg xfpm-phone-080.svg
ln -s gpm-phone-100.svg xfpm-phone-100.svg

# xfpm-ups
ln -s battery-000.svg xfpm-ups-000.svg
ln -s battery-020.svg xfpm-ups-020.svg
ln -s battery-040.svg xfpm-ups-040.svg
ln -s battery-060.svg xfpm-ups-060.svg
ln -s battery-080.svg xfpm-ups-080.svg
ln -s battery-100.svg xfpm-ups-100.svg

ln -s battery-000-charging.svg xfpm-ups-000-charging.svg
ln -s battery-020-charging.svg xfpm-ups-020-charging.svg
ln -s battery-040-charging.svg xfpm-ups-040-charging.svg
ln -s battery-060-charging.svg xfpm-ups-060-charging.svg
ln -s battery-080-charging.svg xfpm-ups-080-charging.svg
ln -s battery-100-charging.svg xfpm-ups-100-charging.svg

ln -s battery-charged.svg xfpm-ups-charged.svg
ln -s battery-000.svg xfpm-ups-empty.svg
ln -s battery-000.svg xfpm-ups-missing.svg